#
# spec file for package ghc-text-ansi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name text-ansi
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        0.3.0.1
Release:        2.2
Summary:        Text styling for ANSI terminals
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-builder-linear-devel
BuildRequires:  ghc-text-builder-linear-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
ExcludeArch:    %{ix86}

%description
Text styling for ANSI terminals using SGR codes, as defined by the
<https://www.ecma-international.org/publications-and-standards/standards/ecma-48
ECMA-48> standard.

Supports foreground/background color, bold/faint intensity, italic,
single/double underline, strikethrough, frame, encircle, and overline escape
sequences. Some styles may not work on your terminal.

Also features terminal detection, so redirecting styled output to a file will
automatically strip the ANSI escape sequences.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu May 16 2024 Peter Simons <psimons@suse.com>
- Update text-ansi to version 0.3.0.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Oct 12 2023 Peter Simons <psimons@suse.com>
- Update text-ansi to version 0.3.0.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/text-ansi-0.3.0.1/src/CHANGELOG.md
* Wed Oct 11 2023 Peter Simons <psimons@suse.com>
- Update text-ansi to version 0.3.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Sep 24 2023 Peter Simons <psimons@suse.com>
- Update text-ansi to version 0.3.0.
  [#]# [0.3.0] - 2023-09-24
  - Switch the underlying text builder from `text-builder` to `text-builder-linear`. This also affects the API provided by
    `Text.Builder.ANSI`; users that were relying on the `Buidler` type from `text-builder` specificially are encouraged
    to simply use older versions of this package until they are able to update their own code to use `text-builder-linear`
    instead.
    The motivation for this change is performance and encoraging the ecosystem to move in the right direction. See the
    `text-builder-linear` project for more details. In a nutshell, it is the superior builder type ;)
* Thu May 11 2023 Peter Simons <psimons@suse.com>
- Add text-ansi at version 0.2.1.1.
